@@ -2,19 +2,20 @@
 use common::sense;     #new features in perl
 use Getopt::Long;      # to command line parsing
 use AnyEvent::HTTP; # use for http requests and etc. methods
-use POSIX;
+use POSIX; # POSIX related stuff
 use Data::Dumper;      # to debug data
+use AnyEvent::CacheDNS ':register'; # dns requests caching
 my $DEBUG      = 0;        #Debug mode. Default is false (0)
 my $verbose    = 0;        #to view the each connection result
 my $timeout    = 60;
-my $count      = 30000;    #number of requests
-my $concurency = 20;       # number of parralle requests
+my $count      = 30000;    #default number of requests
+my $concurency = 20;       # default number of parralle requests
 my $done       = 0;             #number of done requests
 my $url; # the url to test
 my $method = 'GET';        #http method
 my $proxy;                 # proxy server
 my $max_recurse = 10;      # the default recurse number;
-my $useragent = 'Mozilla/5.0 (compatible; U; AnyEvent::HTTPBenchmark/0.08; +http://github.com/shafiev/AnyEvent-HTTPBenchmark)';
+my $useragent = 'Mozilla/5.0 (compatible; U; AnyEvent::HTTPBenchmark/0.09; +http://github.com/shafiev/AnyEvent-HTTPBenchmark)';
 
 #arrays
 my @reqs_time;             # the time of requests
@@ -166,4 +167,4 @@ sub format_seconds {
     return sprintf "%.4f", shift;
 }
 
-1;
+1;
\ No newline at end of file
